<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
      <meta name="viewport" content="width=device-width, initial-scale=1">
      <link rel="stylesheet" href="{{ url_for('static', filename='bootstrap/css/cdn_bootstrap_5-3_min.css') }}">
      <link rel="stylesheet" href="{{ url_for('static', filename='bootstrap/css/bootstrap_docs_5-3.css') }}">
      <script src="{{ url_for('static', filename='bootstrap/js/cdn_bootstrap_5-3.js') }}"></script>
      <title>a2d Instructions</title>
      <link rel="icon" type="image/png" href="{{ url_for('get_image') }}">
  </head>

  <body class="p-3 m-0 border-0 bd-example m-0 border-0">
    <script src="{{ url_for('static', filename='js/input_cursor.js') }}"></script>
    <script src="{{ url_for('static', filename='js/clean_pin.js') }}"></script>
    <script src="{{ url_for('static', filename='js/heartbeat.js') }}"></script>
    <script src="{{ url_for('static', filename='bootstrap/js/bootstrap_5-3_mode.js') }}"></script>
    <script src="{{ url_for('static', filename='js/version.js') }}"></script>

    <!-- Navbar -->
    {% include 'navbar_help.html' %}

    <!-- Help container -->
    {% include 'help.html' %}

    <!-- Footer -->
    <div class="container-fluid" style="margin-left: 0px;">
      {% include 'footer.html' %}
    </div>

  </body>
</html>
